==> jtharness_4.6.orig.tar.xz: jtharness-4.6/src/com/sun/javatest/audit/BadTestDescriptionPane.java <==
/*
 * $Id$
 *
 * Copyright (c) 2002, 2009, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javatest.audit;

import javax.help.CSH;

import com.sun.javatest.tool.UIFactory;


class BadTestDescriptionPane extends ListPane {
    BadTestDescriptionPane(UIFactory uif) {
        super("badTestDesc", uif);
        CSH.setHelpIDString(this, "audit.badTestDescriptionTab.csh");
    }

    void show(Audit audit) {
        if (audit == currAudit)
            showBody();
        else {
            currAudit = audit;
            setData(currAudit.getBadTestDescriptions());
        }
    }

    private Audit currAudit;
}

==> jtharness_5.0.orig.tar.xz: jtharness-5.0/src/com/sun/javatest/audit/BadTestDescriptionPane.java <==
/*
 * $Id$
 *
 * Copyright (c) 2002, 2009, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javatest.audit;

import com.sun.javatest.tool.jthelp.ContextHelpManager;

import com.sun.javatest.tool.UIFactory;


class BadTestDescriptionPane extends ListPane {
    BadTestDescriptionPane(UIFactory uif) {
        super("badTestDesc", uif);
        ContextHelpManager.setHelpIDString(this, "audit.badTestDescriptionTab.csh");
    }

    void show(Audit audit) {
        if (audit == currAudit)
            showBody();
        else {
            currAudit = audit;
            setData(currAudit.getBadTestDescriptions());
        }
    }

    private Audit currAudit;
}
